# Introduction

The SenML library helps you create and parse [senml documents](https://tools.ietf.org/html/draft-ietf-core-senml-13)
in both json and cbor format.

# key features

- Object oriented design.
- built in support for [senml's unit registry](https://tools.ietf.org/html/draft-ietf-core-senml-12#section-12.1)
- extensible for new data types
- direct support to read/write in json and cbor format.
- automatically adjusts record data with respect to base time, base value & base sum.
